cpp_apigen demo
===============

.. warning::

   This functionality is experimental, incomplete and subject to
   backwards-incompatible changes.


Indexing
--------

.. cpp-apigen-group:: indexing


Array
-----

.. cpp-apigen-group:: array
